# zxx

* 北京大学政信社（政信信）女足开发的 Python 库，主要用于剪辑比赛集锦。 / A Python package developed by “Zheng-Xin-She” (formerly “Zheng-Xin-Xin”) Women’s Football Team at Peking University, mainly used for editing game highlights.

* 点击[此处](https://github.com/PKU-Zyf/zxx)前往 zxx 的 GitHub 主页。 / Click [here](https://github.com/PKU-Zyf/zxx) to go to the GitHub homepage of  *zxx*.

* 点击[此处](https://pypi.org/project/zxx)前往 zxx 的 PyPI 主页。 / Click [here](https://pypi.org/project/zxx) to go to the PyPI homepage of *zxx*.

* 安装 / To install: `pip install zxx`.

* 更新 / To update: `pip install --upgrade zxx` / `pip install -U zxx`.

  ## 更新日志 Update Logs

* 0.1.0 (2022-11-07)
  * 第一次正式发布。 / The first release.

* 0.2.0 (2023-04-03)

  * 全面修改运行逻辑。 / An entire modification.

* 1.0.0 (2024-10-24)

  * 修复了一些 bug，简化了使用逻辑，添加了详细的文档字符串（使用说明）和示例代码。 / Fixed some bugs, simplified the usage, and added detailed docstrings and example code.
